import os
import django
import sys

__author__ = "FENG Hao"
__copyright__ = "Copyright (c) " + "25.11.2019" + " FENG Hao"
__licence__ = """BSD-3-Clause Licence"""


def CKINST():
    """function to find problems of the installation."""
    print('I will try to find errors for you!')

    djv = django.VERSION[:2]

    def strform(val):
        """returns formated version tuples"""
        return str(val).strip('()').replace(' ', '').replace(',', '.')

    # Errors
    dja = django.VERSION[:2]
    pyver = sys.version_info[:2]
    error = True
    if not dja >= (2, 0):
        print('')
        print('Hint! Django requires 2.0 or greater which currently is' % dja)
    else:
        error = False
    if not pyver >= (3, 4):
        print('')
        print('Hint! Python requires 3.4 or greater which currently is' % pyver)
    else:
        error = False

    # success message
    if not error:
        print("No errors!")



# Generated by Django 3.1.10 on 2022-02-04 11:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DownloadSite',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('link_key', models.CharField(editable=False, max_length=63, unique=True)),
                ('timestamp_creation', models.DateTimeField(auto_now_add=True, verbose_name='creation time')),
            ],
            options={
                'verbose_name': 'Download Site',
            },
        ),
        migrations.CreateModel(
            name='UploadFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('display_name', models.CharField(max_length=63, unique=True, verbose_name='Display Name')),
                ('file', models.FileField(help_text='Select the file to upload', max_length=255, upload_to='', verbose_name='file')),
            ],
            options={
                'verbose_name': 'Upload File',
            },
        ),
        migrations.CreateModel(
            name='Download',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('active', models.BooleanField(default=True, verbose_name='is active')),
                ('link_key', models.CharField(editable=False, max_length=63, unique=True)),
                ('timestamp_creation', models.DateTimeField(auto_now_add=True, verbose_name='creation time')),
                ('down_file', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='downloads', to='onetimelink.uploadfile')),
                ('site', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='downloads', to='onetimelink.downloadsite')),
            ],
        ),
    ]



from django.urls import re_path

from . import views

app_name = 'OneTimeLink'

urlpatterns = [
    re_path('site/([\w-]*)/$', views.site, name='site'),
    re_path('link/(\w{31})/.*', views.fetch, name='fetch'),
    re_path('downloadsite/$', views.downloadsite, name='downloadsite'),
]



from django.test import TestCase
from django.core.files import File

from onetimelink.models import UploadFile, Download, DownloadSite
from onetimelink.api import file_link_url, site_link_url
from onetimelink import presettings

import os


class Obj:
    pass


class UploadFileCase(TestCase):
    def setUp(self):
        f = open(os.getcwd() + '/media/test.jpg', 'rb')
        UploadFile.objects.create(display_name="test", file=File(f))

    def test_uploaded_file(self):
        down_file = UploadFile.objects.all().last()

        # Clean uploaded file
        os.remove(down_file.file.path)

        self.assertEqual(down_file.display_name, 'test')


class DownloadCase(TestCase):
    def setUp(self):
        f = open(os.getcwd() + '/media/test.jpg', 'rb')
        UploadFile.objects.create(display_name="test", file=File(f))

    def test_download(self):
        down_file = UploadFile.objects.all().last()

        # Clean uploaded file
        os.remove(down_file.file.path)

        d = Download(down_file=down_file)
        d.save()
        self.assertEqual(d.get_path(), d.down_file.file.path)
        request = Obj()
        request.__dict__['META'] = {}
        request.META['HTTP_HOST'] = 'www.example.com'
        link = '%s%s/%s/link/%s/%s' % (
            'http://',
            request.META.get('HTTP_HOST'),
            presettings.DYNAMIC_LINK_URL_BASE_COMPONENT,
            d.link_key,
            d.get_filename()
        )
        self.assertEqual(file_link_url(request, d), link)


class DownloadSiteCase(TestCase):
    def setUp(self):
        f = open(os.getcwd() + '/media/test.jpg', 'rb')
        UploadFile.objects.create(display_name="test", file=File(f))

    def test_download(self):
        down_file = UploadFile.objects.all().last()

        # Clean uploaded file
        os.remove(down_file.file.path)

        sd = DownloadSite()
        sd.save()
        for down_file in UploadFile.objects.all():
            d = Download(site=sd, down_file=down_file)
            d.save()
        request = Obj()
        request.__dict__['META'] = {}
        request.META['HTTP_HOST'] = 'www.example.com'
        link = '%s%s/%s/site/%s' % (
            'http://',
            request.META.get(
                'HTTP_HOST'),
            presettings.DYNAMIC_LINK_URL_BASE_COMPONENT,
            sd.link_key
        )
        self.assertEqual(site_link_url(request, sd), link)
